@@ -1,6 +1,6 @@
 /**
  *
- * $Id: Host.c,v 1.30 2004/08/22 15:49:38 rwscott Exp $
+ * $Id: Host.c,v 1.32 2005/09/15 14:10:08 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  * Copyright  1999-2001 by the LessTif developers.
@@ -56,7 +56,7 @@
 
 #undef DEBUG
 
-static const char rcsid[] = "$Id: Host.c,v 1.30 2004/08/22 15:49:38 rwscott Exp $";
+static const char rcsid[] = "$Id: Host.c,v 1.32 2005/09/15 14:10:08 rwscott Exp $";
 
 typedef struct
 {
@@ -959,6 +959,7 @@ initialize(Widget request, Widget new_w, ArgList args, Cardinal *num_args)
     Host_BinaryTimeOutId(new_w) = (XtIntervalId)NULL;
     Host_NumClients(new_w) = 0;
     Host_ClientList(new_w) = NULL;
+    Host_SaveDialog(new_w) = NULL;
     if (Host_Terminator(new_w) == NULL)
     {
 	Host_Terminator(new_w) = XtNewString("\r\n");
@@ -991,6 +992,10 @@ destroy(Widget w)
     {
 	XtDestroyWidget(Host_Dialog(w));
     }
+    if (Host_SaveDialog(w))
+    {
+	XtDestroyWidget(Host_SaveDialog(w));
+    }
 }
 
 static Boolean
@@ -1231,3 +1236,13 @@ XltHelpOnHostSelect(Widget W)
     }
     XtManageChild(Dialog);
 }
+
+/* ******************** */
+
+void
+XltHostReconnect(Widget w)
+{
+    Disconnect(w);
+    XtAppAddTimeOut(XtWidgetToApplicationContext(w),
+		    1000, (XtTimerCallbackProc)Connect, w);
+}
