@@ -1,6 +1,6 @@
 /**
  *
- * $Id: NumEntry.c,v 1.17 2004/07/11 14:57:48 rwscott Exp $
+ * $Id: NumEntry.c,v 1.18 2005/09/03 12:50:17 rwscott Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
  * Copyright  1999-2001 by the LessTif developers.
@@ -46,7 +46,7 @@
 
 #undef DEBUG
 
-static const char rcsid[] = "$Id: NumEntry.c,v 1.17 2004/07/11 14:57:48 rwscott Exp $";
+static const char rcsid[] = "$Id: NumEntry.c,v 1.18 2005/09/03 12:50:17 rwscott Exp $";
 
 /*
    Widget methods, forward declarations
@@ -645,6 +645,10 @@ set_values(Widget old, Widget request, Widget new_w, ArgList args, Cardinal *num
 	Place = XmTextFieldGetInsertionPosition(NumEntry_TextField(new_w));
 	XmTextFieldSetString(NumEntry_TextField(new_w), NumEntry_Value(new_w));
 	XmTextFieldSetInsertionPosition(NumEntry_TextField(new_w), Place);
+	if (NumEntry_Value(old))
+	{
+	    XtFree(NumEntry_Value(old));
+	}
 	refresh = True;
 	DoMath(new_w);
     }
